@@ -1,5 +1,5 @@
 /*
-    i801.c - Part of lm_sensors, Linux kernel modules for hardware
+    i2c-i801.c - Part of lm_sensors, Linux kernel modules for hardware
               monitoring
     Copyright (c) 1998 - 2002  Frodo Looijaard <frodol@dds.nl>,
     Philip Edelbrock <phil@netroedge.com>, and Mark D. Studebaker
@@ -32,6 +32,9 @@
     ICH6		266A   ("")
     ICH7		27DA   ("")
     ESB2 		269B   ("")
+    ICH8		283E   ("")
+    ICH9		2930   ("")
+
     This driver supports several versions of Intel's I/O Controller Hubs (ICH).
     For SMBus support, they are similar to the PIIX4 and are part
     of Intel's '810' and other chipsets.
@@ -91,6 +94,16 @@
 #define PCI_DEVICE_ID_INTEL_ICH7_17	0x27da
 #endif
 
+/* ICH8 is undefined */
+#ifndef PCI_DEVICE_ID_INTEL_ICH8_5
+#define PCI_DEVICE_ID_INTEL_ICH8_5	0x283e
+#endif
+
+/* ICH9 is undefined */
+#ifndef PCI_DEVICE_ID_INTEL_ICH9_6
+#define PCI_DEVICE_ID_INTEL_ICH9_6	0x2930
+#endif
+
 #ifdef I2C_CLIENT_PEC
 #define HAVE_PEC
 #endif
@@ -154,28 +167,25 @@ static struct pci_dev *I801_dev;
 static int isich4;	/* is PEC supported? */
 static int isich5;	/* is i2c block read supported? */
 
-static int i801_setup(struct pci_dev *dev)
+static int __devinit i801_setup(struct pci_dev *dev)
 {
-	int error_return = 0;
 	unsigned char temp;
 
-	/* Note: we keep on searching until we have found 'function 3' */
-	if(PCI_FUNC(dev->devfn) != 3)
-		return -ENODEV;
-
 	I801_dev = dev;
 	if (dev->device == PCI_DEVICE_ID_INTEL_82801DB_3 ||
 	    dev->device == PCI_DEVICE_ID_INTEL_82801EB_3 ||
 	    dev->device == PCI_DEVICE_ID_INTEL_ESB_4 ||
 	    dev->device == PCI_DEVICE_ID_INTEL_ESB2_17 ||	
 	    dev->device == PCI_DEVICE_ID_INTEL_ICH6_16 ||
-	    dev->device == PCI_DEVICE_ID_INTEL_ICH7_17)
+	    dev->device == PCI_DEVICE_ID_INTEL_ICH7_17 ||
+	    dev->device == PCI_DEVICE_ID_INTEL_ICH8_5 ||
+	    dev->device == PCI_DEVICE_ID_INTEL_ICH9_6)
 		isich4 = 1;
 	else
 		isich4 = 0;
 	isich5 = isich4 && dev->device != PCI_DEVICE_ID_INTEL_82801DB_3;
 
-	/* Determine the address of the SMBus areas */
+	/* Determine the address of the SMBus area */
 	if (force_addr) {
 		i801_smba = force_addr & 0xfff0;
 	} else {
@@ -191,8 +201,7 @@ static int i801_setup(struct pci_dev *dev)
 	if (!request_region(i801_smba, (isich4 ? 16 : 8), i801_driver.name)) {
 		dev_err(dev, "I801_smb region 0x%x already in use!\n",
 			i801_smba);
-		error_return = -EBUSY;
-		goto END;
+		return -EBUSY;
 	}
 
 	pci_read_config_byte(I801_dev, SMBHSTCFG, &temp);
@@ -202,17 +211,20 @@ static int i801_setup(struct pci_dev *dev)
 	/* If force_addr is set, we program the new address here. Just to make
 	   sure, we disable the device first. */
 	if (force_addr) {
-		pci_write_config_byte(I801_dev, SMBHSTCFG, temp & 0xfe);
+		pci_write_config_byte(I801_dev, SMBHSTCFG,
+				      temp & ~SMBHSTCFG_HST_EN);
 		pci_write_config_word(I801_dev, SMBBA, i801_smba);
-		pci_write_config_byte(I801_dev, SMBHSTCFG, temp | 0x01);
+		pci_write_config_byte(I801_dev, SMBHSTCFG,
+				      temp | SMBHSTCFG_HST_EN);
 		dev_warn(dev, "WARNING: I801 SMBus interface set to "
 			"new address %04x!\n", i801_smba);
-	} else if ((temp & 1) == 0) {
-		pci_write_config_byte(I801_dev, SMBHSTCFG, temp | 1);
+	} else if (!(temp & SMBHSTCFG_HST_EN)) {
+		pci_write_config_byte(I801_dev, SMBHSTCFG,
+				      temp | SMBHSTCFG_HST_EN);
 		dev_warn(dev, "enabling SMBus device\n");
 	}
 
-	if (temp & 0x02)
+	if (temp & SMBHSTCFG_SMB_SMI_EN)
 		dev_dbg(dev, "I801 using Interrupt SMI# for SMBus.\n");
 	else
 		dev_dbg(dev, "I801 using PCI Interrupt for SMBus.\n");
@@ -221,8 +233,7 @@ static int i801_setup(struct pci_dev *dev)
 	dev_dbg(dev, "SMBREV = 0x%X\n", temp);
 	dev_dbg(dev, "I801_smba = 0x%X\n", i801_smba);
 
-END:
-	return error_return;
+	return 0;
 }
 
 
@@ -247,7 +258,7 @@ static int i801_transaction(void)
 			dev_dbg(I801_dev, "Failed! (%02x)\n", temp);
 			return -1;
 		} else {
-			dev_dbg(I801_dev, "Successfull!\n");
+			dev_dbg(I801_dev, "Successful!\n");
 		}
 	}
 
@@ -385,8 +396,8 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 		/* We will always wait for a fraction of a second! */
 		timeout = 0;
 		do {
-			temp = inb_p(SMBHSTSTS);
 			i2c_delay(1);
+			temp = inb_p(SMBHSTSTS);
 		}
 		    while ((!(temp & 0x80))
 			   && (timeout++ < MAX_TIMEOUT));
@@ -449,8 +460,8 @@ static int i801_block_transaction(union i2c_smbus_data *data, char read_write,
 		/* wait for INTR bit as advised by Intel */
 		timeout = 0;
 		do {
-			temp = inb_p(SMBHSTSTS);
 			i2c_delay(1);
+			temp = inb_p(SMBHSTSTS);
 		} while ((!(temp & 0x02))
 			   && (timeout++ < MAX_TIMEOUT));
 
@@ -537,6 +548,11 @@ static s32 i801_access(struct i2c_adapter * adap, u16 addr,
 		ret = i801_transaction();
 	}
 
+	/* Some BIOSes don't like it when PEC is enabled at reboot or resume
+	   time, so we forcibly disable it after every transaction. */
+	if (hwpec)
+		outb_p(0, SMBAUXCTL);
+
 	if(block)
 		return ret;
 	if(ret)
@@ -660,17 +676,27 @@ static struct pci_device_id i801_ids[] __devinitdata = {
 		.subvendor =	PCI_ANY_ID,
 		.subdevice =	PCI_ANY_ID,
 	},
+	{
+		.vendor =	PCI_VENDOR_ID_INTEL,
+		.device =	PCI_DEVICE_ID_INTEL_ICH8_5,
+		.subvendor =	PCI_ANY_ID,
+		.subdevice =	PCI_ANY_ID,
+	},
+	{
+		.vendor =	PCI_VENDOR_ID_INTEL,
+		.device =	PCI_DEVICE_ID_INTEL_ICH9_6,
+		.subvendor =	PCI_ANY_ID,
+		.subdevice =	PCI_ANY_ID,
+	},
 	{ 0, }
 };
 
 static int __devinit i801_probe(struct pci_dev *dev, const struct pci_device_id *id)
 {
+	int err;
 
-	if (i801_setup(dev)) {
-		dev_warn(dev,
-			"I801 not detected, module not inserted.\n");
-		return -ENODEV;
-	}
+	if ((err = i801_setup(dev)))
+		return err;
 
 	snprintf(i801_adapter.name, 32,
 		"SMBus I801 adapter at %04x", i801_smba);
