@@ -184,6 +184,30 @@
 #define SENSORS_ADM1021_ALARMS 81 /* R */
 #define SENSORS_ADM1021_DIE_CODE 90 /* R */
 
+/* ADM1029 chips */
+
+#define SENSORS_ADM1029_PREFIX "adm1029"
+
+#define SENSORS_ADM1029_TEMP1		51
+#define SENSORS_ADM1029_TEMP1_MAX	52
+#define SENSORS_ADM1029_TEMP1_MIN	53
+
+#define SENSORS_ADM1029_TEMP2		61
+#define SENSORS_ADM1029_TEMP2_MAX	62
+#define SENSORS_ADM1029_TEMP2_MIN	63
+
+#define SENSORS_ADM1029_TEMP3		71
+#define SENSORS_ADM1029_TEMP3_MAX	72
+#define SENSORS_ADM1029_TEMP3_MIN	73
+
+#define SENSORS_ADM1029_FAN1		81
+#define SENSORS_ADM1029_FAN1_MIN	82
+#define SENSORS_ADM1029_FAN1_DIV	83
+
+#define SENSORS_ADM1029_FAN2		91
+#define SENSORS_ADM1029_FAN2_MIN	92
+#define SENSORS_ADM1029_FAN2_DIV	93
+
 
 /* ADM1030 and ADM1031 chips */
 
@@ -728,6 +752,29 @@
 #define SENSORS_W83792D_FAN7_DIV 77 /* RW */
 
 
+/* Winbond W83793R chip */
+#define SENSORS_W83793_PREFIX "w83793"
+
+#define SENSORS_W83793_IN(n)		(0 + (n))  /* n(0-9) R */
+#define SENSORS_W83793_IN_MIN(n)	(20 + (n)) /* n(0-9) RW */
+#define SENSORS_W83793_IN_MAX(n)	(40 + (n)) /* n(0-9) RW */
+#define SENSORS_W83793_IN_ALARM(n)	(60 + (n)) /* n(0-9) R */
+
+#define SENSORS_W83793_FAN(n)		(80 + (n))  /* n(1-12) R */
+#define SENSORS_W83793_FAN_MIN(n)	(100 + (n)) /* n(1-12) RW */
+#define SENSORS_W83793_FAN_ALARM(n)	(120 + (n)) /* n(1-12) R */
+
+
+#define SENSORS_W83793_TEMP(n)		(140 + (n)) /* n(1-6) R */
+#define SENSORS_W83793_TEMP_CRIT(n)	(160 + (n)) /* n(1-6) RW */
+#define SENSORS_W83793_TEMP_CRIT_HYST(n) (180 + (n)) /* n(1-6) RW */
+#define SENSORS_W83793_TEMP_ALARM(n)	(200 + (n)) /* n(1-6) R */
+
+#define SENSORS_W83793_VID0		221 /* R */
+#define SENSORS_W83793_VID1		222 /* R */
+#define SENSORS_W83793_VRM		230 /* RW */
+#define SENSORS_W83793_CHASSIS		240 /* RW */
+
 
 #define SENSORS_AS99127F_PREFIX "as99127f"
 
@@ -845,15 +892,62 @@
 #define SENSORS_W83L785TS_TEMP_OVER	52 /* R for now */
 
 
-/* Winbond W83627EHF Super-I/O chips */
+/* Winbond W83627EHF & W83627DHG Super-I/O chips */
+/* (W83627DHG is similar to W83627EHF but no in9) */
 
 #define SENSORS_W83627EHF_PREFIX	"w83627ehf"
+#define SENSORS_W83627DHG_PREFIX	"w83627dhg"
 
+#define SENSORS_W83627EHF_IN0		1 /* R */
+#define SENSORS_W83627EHF_IN1		2 /* R */
+#define SENSORS_W83627EHF_IN2		3 /* R */
+#define SENSORS_W83627EHF_IN3		4 /* R */
+#define SENSORS_W83627EHF_IN4		5 /* R */
+#define SENSORS_W83627EHF_IN5		6 /* R */
+#define SENSORS_W83627EHF_IN6		7 /* R */
+#define SENSORS_W83627EHF_IN7		8 /* R */
+#define SENSORS_W83627EHF_IN8		9 /* R */
+#define SENSORS_W83627EHF_IN9 		10 /* R */
+#define SENSORS_W83627EHF_IN0_ALARM	111 /* R */
+#define SENSORS_W83627EHF_IN1_ALARM	112 /* R */
+#define SENSORS_W83627EHF_IN2_ALARM	113 /* R */
+#define SENSORS_W83627EHF_IN3_ALARM	114 /* R */
+#define SENSORS_W83627EHF_IN4_ALARM	115 /* R */
+#define SENSORS_W83627EHF_IN5_ALARM	116 /* R */
+#define SENSORS_W83627EHF_IN6_ALARM	117 /* R */
+#define SENSORS_W83627EHF_IN7_ALARM	118 /* R */
+#define SENSORS_W83627EHF_IN8_ALARM	119 /* R */
+#define SENSORS_W83627EHF_IN9_ALARM	120 /* R */
+#define SENSORS_W83627EHF_IN0_MIN	11 /* RW */
+#define SENSORS_W83627EHF_IN1_MIN	12 /* RW */
+#define SENSORS_W83627EHF_IN2_MIN	13 /* RW */
+#define SENSORS_W83627EHF_IN3_MIN	14 /* RW */
+#define SENSORS_W83627EHF_IN4_MIN	15 /* RW */
+#define SENSORS_W83627EHF_IN5_MIN	16 /* RW */
+#define SENSORS_W83627EHF_IN6_MIN	17 /* RW */
+#define SENSORS_W83627EHF_IN7_MIN	18 /* RW */
+#define SENSORS_W83627EHF_IN8_MIN	19 /* RW */
+#define SENSORS_W83627EHF_IN9_MIN	20 /* RW */
+#define SENSORS_W83627EHF_IN0_MAX	21 /* RW */
+#define SENSORS_W83627EHF_IN1_MAX	22 /* RW */
+#define SENSORS_W83627EHF_IN2_MAX	23 /* RW */
+#define SENSORS_W83627EHF_IN3_MAX	24 /* RW */
+#define SENSORS_W83627EHF_IN4_MAX	25 /* RW */
+#define SENSORS_W83627EHF_IN5_MAX	26 /* RW */
+#define SENSORS_W83627EHF_IN6_MAX	27 /* RW */
+#define SENSORS_W83627EHF_IN7_MAX	28 /* RW */
+#define SENSORS_W83627EHF_IN8_MAX	29 /* RW */
+#define SENSORS_W83627EHF_IN9_MAX	30 /* RW */
 #define SENSORS_W83627EHF_FAN1		31 /* R  */
 #define SENSORS_W83627EHF_FAN2		32 /* R  */
 #define SENSORS_W83627EHF_FAN3		33 /* R  */
 #define SENSORS_W83627EHF_FAN4		34 /* R  */
 #define SENSORS_W83627EHF_FAN5		35 /* R  */
+#define SENSORS_W83627EHF_FAN1_ALARM	131 /* R  */
+#define SENSORS_W83627EHF_FAN2_ALARM	132 /* R  */
+#define SENSORS_W83627EHF_FAN3_ALARM	133 /* R  */
+#define SENSORS_W83627EHF_FAN4_ALARM	134 /* R  */
+#define SENSORS_W83627EHF_FAN5_ALARM	135 /* R  */
 #define SENSORS_W83627EHF_FAN1_MIN	41 /* RW */
 #define SENSORS_W83627EHF_FAN2_MIN	42 /* RW */
 #define SENSORS_W83627EHF_FAN3_MIN	43 /* RW */
@@ -867,6 +961,9 @@
 #define SENSORS_W83627EHF_TEMP1		61 /* R  */
 #define SENSORS_W83627EHF_TEMP2		62 /* R  */
 #define SENSORS_W83627EHF_TEMP3		63 /* R  */
+#define SENSORS_W83627EHF_TEMP1_ALARM	161 /* R  */
+#define SENSORS_W83627EHF_TEMP2_ALARM	162 /* R  */
+#define SENSORS_W83627EHF_TEMP3_ALARM	163 /* R  */
 #define SENSORS_W83627EHF_TEMP1_OVER	71 /* RW */
 #define SENSORS_W83627EHF_TEMP2_OVER	72 /* RW */
 #define SENSORS_W83627EHF_TEMP3_OVER	73 /* RW */
@@ -1493,6 +1590,8 @@
 
 #define SENSORS_IT87_PREFIX "it87"
 #define SENSORS_IT8712_PREFIX "it8712"
+#define SENSORS_IT8716_PREFIX "it8716"
+#define SENSORS_IT8718_PREFIX "it8718"
 
 #define SENSORS_IT87_IN0 1 /* R */
 #define SENSORS_IT87_IN1 2 /* R */
@@ -1690,21 +1789,18 @@
 #define SENSORS_VT1211_IN3 4 /* R */
 #define SENSORS_VT1211_IN4 5 /* R */
 #define SENSORS_VT1211_IN5 6 /* R */
-#define SENSORS_VT1211_IN6 7 /* R */
 #define SENSORS_VT1211_IN0_MIN 11 /* RW */
 #define SENSORS_VT1211_IN1_MIN 12 /* RW */
 #define SENSORS_VT1211_IN2_MIN 13 /* RW */
 #define SENSORS_VT1211_IN3_MIN 14 /* RW */
 #define SENSORS_VT1211_IN4_MIN 15 /* RW */
 #define SENSORS_VT1211_IN5_MIN 16 /* RW */
-#define SENSORS_VT1211_IN6_MIN 17 /* RW */
 #define SENSORS_VT1211_IN0_MAX 21 /* RW */
 #define SENSORS_VT1211_IN1_MAX 22 /* RW */
 #define SENSORS_VT1211_IN2_MAX 23 /* RW */
 #define SENSORS_VT1211_IN3_MAX 24 /* RW */
 #define SENSORS_VT1211_IN4_MAX 25 /* RW */
 #define SENSORS_VT1211_IN5_MAX 26 /* RW */
-#define SENSORS_VT1211_IN6_MAX 27 /* RW */
 #define SENSORS_VT1211_FAN1 31 /* R */
 #define SENSORS_VT1211_FAN2 32 /* R */
 #define SENSORS_VT1211_FAN1_MIN 41 /* RW */
@@ -1738,15 +1834,34 @@
 #define SENSORS_VT1211_UCH 84 /* RW */
 
 #define SENSORS_SMSC47M1_PREFIX "smsc47m1"
+#define SENSORS_SMSC47M2_PREFIX "smsc47m2"
 
 #define SENSORS_SMSC47M1_FAN1 31 /* R */
 #define SENSORS_SMSC47M1_FAN2 32 /* R */
+#define SENSORS_SMSC47M1_FAN3 33 /* R */
 #define SENSORS_SMSC47M1_FAN1_MIN 41 /* RW */
 #define SENSORS_SMSC47M1_FAN2_MIN 42 /* RW */
+#define SENSORS_SMSC47M1_FAN3_MIN 43 /* RW */
 #define SENSORS_SMSC47M1_FAN1_DIV 75 /* RW */
 #define SENSORS_SMSC47M1_FAN2_DIV 76 /* RW */
+#define SENSORS_SMSC47M1_FAN3_DIV 77 /* RW */
 #define SENSORS_SMSC47M1_ALARMS 81 /* R */
 
+#define SENSORS_SMSC47M192_PREFIX "smsc47m192"
+
+#define SENSORS_SMSC47M192_IN(n)		(1 + (n))	/* R */
+#define SENSORS_SMSC47M192_IN_MIN(n)		(21 + (n))	/* RW */
+#define SENSORS_SMSC47M192_IN_MAX(n)		(41 + (n))	/* RW */
+#define SENSORS_SMSC47M192_IN_ALARM(n)		(61 + (n))	/* R */
+#define SENSORS_SMSC47M192_TEMP(n)		(100 + (n))	/* R */
+#define SENSORS_SMSC47M192_TEMP_MAX(n)		(120 + (n))	/* RW */
+#define SENSORS_SMSC47M192_TEMP_MIN(n)		(140 + (n))	/* RW */
+#define SENSORS_SMSC47M192_TEMP_OFFSET(n)	(160 + (n))	/* RW */
+#define SENSORS_SMSC47M192_TEMP_ALARM(n)	(180 + (n))	/* R */
+#define SENSORS_SMSC47M192_TEMP_FAULT(n)	(200 + (n))	/* R */
+#define SENSORS_SMSC47M192_VID			301		/* R */
+#define SENSORS_SMSC47M192_VRM			302		/* RW */
+
 #define SENSORS_PC87360_PREFIX "pc87360"
 #define SENSORS_PC87363_PREFIX "pc87363"
 #define SENSORS_PC87364_PREFIX "pc87364"
@@ -1848,6 +1963,14 @@
 #define SENSORS_PC87360_VID		240	/* R */
 #define SENSORS_PC87360_VRM		241	/* RW */
 
+#define SENSORS_PC87427_PREFIX "pc87427"
+
+/* fan n from 1 to 8 */
+#define SENSORS_PC87427_FAN(n)		(n)		/* R */
+#define SENSORS_PC87427_FAN_MIN(n)	(16 + (n))	/* RW */
+#define SENSORS_PC87427_FAN_ALARM(n)	(32 + (n))	/* R */
+#define SENSORS_PC87427_FAN_FAULT(n)	(48 + (n))	/* R */
+
 #define SENSORS_LM92_PREFIX "lm92"
 
 #define SENSORS_LM92_TEMP_HIGH		1	/* RW */
@@ -2085,10 +2208,11 @@
 #define SENSORS_SMSC47B397_FAN3		0x13 /* R */
 #define SENSORS_SMSC47B397_FAN4		0x14 /* R */
 
-/* Fintek F71805F chip */
+/* Fintek F71805F/FG and F71872F/FG chips */
 #define SENSORS_F71805F_PREFIX		"f71805f"
+#define SENSORS_F71872F_PREFIX		"f71872f"
 
-/* in n from 0 to 8 */
+/* in n from 0 to 10 */
 #define SENSORS_F71805F_IN(n)		(1 + (n))
 #define SENSORS_F71805F_IN_MIN(n)	(16 + (n))
 #define SENSORS_F71805F_IN_MAX(n)	(31 + (n))
@@ -2105,4 +2229,37 @@
 #define SENSORS_F71805F_ALARMS_FAN	201
 #define SENSORS_F71805F_ALARMS_TEMP	202
 
+/* Abit uGuru chip */
+#define SENSORS_ABITUGURU_PREFIX "abituguru"
+
+/* in n from 0 to 10 */
+#define SENSORS_ABITUGURU_IN(n)			(0x01 + (n)) /* R */
+#define SENSORS_ABITUGURU_IN_MIN(n)		(0x11 + (n)) /* RW */
+#define SENSORS_ABITUGURU_IN_MIN_ALARM(n)	(0x21 + (n)) /* R */
+#define SENSORS_ABITUGURU_IN_MAX(n)		(0x31 + (n)) /* RW */
+#define SENSORS_ABITUGURU_IN_MAX_ALARM(n)	(0x41 + (n)) /* R */
+/* temp n from 1 to 7 */
+#define SENSORS_ABITUGURU_TEMP(n)		(0x50 + (n)) /* R */
+#define SENSORS_ABITUGURU_TEMP_ALARM(n)		(0x60 + (n)) /* R */
+#define SENSORS_ABITUGURU_TEMP_MAX(n)		(0x70 + (n)) /* RW */
+#define SENSORS_ABITUGURU_TEMP_CRIT(n)		(0x80 + (n)) /* RW */
+/* fan n from 1 to 6 */
+#define SENSORS_ABITUGURU_FAN(n)		(0x90 + (n)) /* R */
+#define SENSORS_ABITUGURU_FAN_ALARM(n)		(0xA0 + (n)) /* R */
+#define SENSORS_ABITUGURU_FAN_MIN(n)		(0xB0 + (n)) /* RW */
+
+/* K8TEMP */
+#define SENSORS_K8TEMP_PREFIX "k8temp"
+#define SENSORS_K8TEMP_TEMP1	0x01 /* R */
+#define SENSORS_K8TEMP_TEMP2	0x02 /* R */
+#define SENSORS_K8TEMP_TEMP3	0x03 /* R */
+#define SENSORS_K8TEMP_TEMP4	0x04 /* R */
+
+/* coretemp */
+
+#define SENSORS_CORETEMP_PREFIX "coretemp"
+#define SENSORS_CORETEMP_TEMP1			0x01 /* R */
+#define SENSORS_CORETEMP_TEMP1_CRIT		0x02 /* R */
+#define SENSORS_CORETEMP_TEMP1_CRIT_ALARM	0x03 /* R */
+
 #endif /* def LIB_SENSORS_CHIPS_H */
